@@ -177,6 +177,9 @@ class Gencontrol(Base):
         if self.config.merge('packages').get('tools-versioned', True):
             packages.extend(self.process_packages(
                 self.templates["control.tools-versioned"], self.vars))
+        if self.config.merge('packages').get('source', True):
+            packages.extend(self.process_packages(
+                self.templates["control.sourcebin"], self.vars))
 
         self._substitute_file('perf.lintian-overrides', self.vars,
                               'debian/linux-perf-%s.lintian-overrides' %
